/** Provides a method for sorting arrays of strings
 *  as well as a main method that shows off its
 *  power.
 *  @author Josh Hug
 */


public class Sort {

	/** Puts a in lexicographic order. */	
	public static void sort(String[] a) {
		sort(a, 0);
	}

	/** Sorts the array a, but starting at start.
	    Everything to the left of start is 'fixed' */
	private static void sort(String[] a, int start) {
		/*{
			1. Find the smallest unfixed item
			2. Move smallest to the front of the unfixed items, and fix it.
			3. Selection sort the remaining unfixed items.
		}*/
		if (a.length == start)
			return;
		int minDex = indexOfSmallest(a, start); 
		swap(a, start, minDex);
		sort(a, start + 1);
	}

	/** Returns the index of the lexicographically smallest
	 *  string in a, starting from position start 
     *
     *  Example:
     *  indexOfSmallest(["bat", "cow", "apple", "fit"], 1) == 2
	 */

	public static int indexOfSmallest(String[] a, int start) {
		//assume smallest string is at start
		int minDex = start;
		for (int i = start; i < a.length; i++) {
			int cmp = a[i].compareTo(a[minDex]);
			// if a[i] < a[minDex], cmp will be negative 

			if (cmp < 0) {
				minDex = i;
			}
		}
		return minDex;
	}

	/** Swaps items in positions ix and iy.  
	 */
	private static void swap(String[] a, int ix, int iy) {
		String temp = a[ix];
		a[ix] = a[iy];
		a[iy] = temp;
	}


	/** This prints the array a.
	 */
	private static void print(String[] a) {
	}

	/** Prints out the command line arguments
	 *  in sorted order. Here sorted means 
	 *  lexicographic order (same as a dictionary).
	 */

	public static void main(String[] args) {
		sort(args);
		print(args);
	}
} 